@@ -30,7 +30,7 @@
 
 from startrek import Hub, Channel, Connection, ConnectionDelegate
 from startrek import ConnectionState, ConnectionStateMachine
-from startrek import BaseHub, BaseChannel, BaseConnection
+from startrek import BaseHub, BaseChannel, BaseConnection, ActiveConnection
 
 from startrek import Ship, ShipDelegate, Arrival, Departure, DeparturePriority
 from startrek import Docker, Gate, GateStatus, GateDelegate
@@ -50,7 +50,7 @@ __all__ = [
 
     'Hub', 'Channel', 'Connection', 'ConnectionDelegate',
     'ConnectionState', 'ConnectionStateMachine',
-    'BaseHub', 'BaseChannel', 'BaseConnection',
+    'BaseHub', 'BaseChannel', 'BaseConnection', 'ActiveConnection',
     'Ship', 'ShipDelegate', 'Arrival', 'Departure', 'DeparturePriority',
     'Docker', 'Gate', 'GateStatus', 'GateDelegate',
     'ArrivalShip', 'ArrivalHall', 'DepartureShip', 'DepartureHall',
@@ -58,5 +58,7 @@ __all__ = [
 
     'PackageArrival', 'PackageDeparture', 'PackageDocker',
 
-    'PackageChannel', 'PackageHub', 'ServerHub', 'ClientHub',
+    'PackageChannel',
+    'PackageHub',
+    'ServerHub', 'ClientHub',
 ]
