@@ -34,7 +34,7 @@ from typing import Optional, Dict, Set
 
 from startrek import Channel
 from startrek import Connection, ConnectionDelegate
-from startrek import BaseConnection
+from startrek import BaseConnection, ActiveConnection
 from startrek import BaseHub
 
 from .channel import PackageChannel
@@ -110,7 +110,7 @@ class ServerHub(PackageHub):
     # Override
     def _create_connection(self, sock: Channel, remote: tuple, local: Optional[tuple]) -> Optional[Connection]:
         gate = self.delegate
-        conn = BaseConnection(remote=remote, local=None, channel=sock, activated=False, delegate=gate, hub=self)
+        conn = BaseConnection(remote=remote, local=None, channel=sock, delegate=gate, hub=self)
         conn.start()  # start FSM
         return conn
 
@@ -121,6 +121,6 @@ class ClientHub(PackageHub):
     # Override
     def _create_connection(self, sock: Channel, remote: tuple, local: Optional[tuple]) -> Optional[Connection]:
         gate = self.delegate
-        conn = BaseConnection(remote=remote, local=None, channel=sock, activated=True, delegate=gate, hub=self)
+        conn = ActiveConnection(remote=remote, local=None, channel=sock, delegate=gate, hub=self)
         conn.start()  # start FSM
         return conn
